*drawtype* argument to RectangleSelector
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
The *drawtype* keyword argument to
`~matplotlib.widgets.RectangleSelector` is deprecated. In the future the
behaviour will be the default behaviour of ``drawtype='box'``.

Support for ``drawtype=line`` will be removed altogether as it is not clear
which points are within and outside a selector that is just a line.
As a result, the ``lineprops`` keyword argument to
`~matplotlib.widgets.RectangleSelector` is also deprecated.

To retain the behaviour of ``drawtype='none'``, use
``rectprops={'visible': False}`` to make the drawn
`~matplotlib.patches.Rectangle` invisible.

These changes also apply to `~matplotlib.widgets.EllipseSelector`, which
is a sub-class of `~matplotlib.widgets.RectangleSelector`. 
